@@ -1,6 +1,4 @@
 /*
- * $ReleaseVersion: 0.1.6 $
- *
  * This program must be called with the constant name as the CONSTANT_NAME
  * define. If this is not the case, then a generic version which takes a
  * symbol to undefine as the first argument will be built.
@@ -8,6 +6,36 @@
 
 #include <config.h>
 
+#ifdef HAVE_SYS_CONF_H
+# ifdef HAVE_SYS_PARAM_H
+# include <sys/param.h>
+# endif
+# ifdef HAVE_TIME_H
+# include <time.h>
+# endif
+#include <sys/conf.h>
+#endif
+
+#ifdef HAVE_SYS_FILE_H
+#include <sys/file.h>
+#endif
+
+#ifdef HAVE_SYS_IOCTL_H
+#include <sys/ioctl.h>
+#endif
+
+#ifdef HAVE_SYS_SOCKET_H
+#include <sys/socket.h>
+#endif
+
+#ifdef HAVE_SYS_SYSTEMINFO_H
+#include <sys/systeminfo.h>
+#endif
+
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
 #endif
@@ -44,36 +72,6 @@
 #include <stropts.h>
 #endif
 
-#ifdef HAVE_SYS_CONF_H
-# ifdef HAVE_SYS_PARAM_H
-# include <sys/param.h>
-# endif
-# ifdef HAVE_TIME_H
-# include <time.h>
-# endif
-#include <sys/conf.h>
-#endif
-
-#ifdef HAVE_SYS_FILE_H
-#include <sys/file.h>
-#endif
-
-#ifdef HAVE_SYS_IOCTL_H
-#include <sys/ioctl.h>
-#endif
-
-#ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>
-#endif
-
-#ifdef HAVE_SYS_SYSTEMINFO_H
-#include <sys/systeminfo.h>
-#endif
-
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #ifdef HAVE_TERMIO_H
 #include <termio.h>
 #endif
@@ -86,6 +84,9 @@
 #define Win32_Winsock
 #include <windows.h>
 /* This directive is checked only for mingw32 2.8.1 */
+#if (_WIN32_WINNT >= 0x0400)
+#include <ws2tcpip.h>
+#endif
 
 /* Absent declarations */
 #define POLLIN 1
@@ -109,6 +110,8 @@
 #define ECONNREFUSED	WSAECONNREFUSED
 #endif
 
+#include <ctype.h>
+
 static char *
 capitalize (char *name)
 {
@@ -121,8 +124,8 @@ capitalize (char *name)
       beginning = 0;
     } else if (*ptr == '_') {
       beginning = 1;
-    } else {
-      *ptr += 'a' - 'A';
+    } else if (isupper(*ptr)) {
+      *ptr = tolower(*ptr);
     }
   }
   *ptr = '\0';
